@@ -15,9 +15,15 @@ try:
     from functools import reduce
 except ImportError:
     pass
+have_vtk = False
+try:
+    import vtk
+    have_vtk = True
+except ImportError:
+    pass
 
 from ._transform_types import to_itk_image, to_point_set, to_geometry
-from ipydatawidgets import array_serialization
+from ipydatawidgets import array_serialization, NDArray
 
 # from IPython.core.debugger import set_trace
 
@@ -295,23 +301,29 @@ def image_point_from_json(js, manager=None):
     if js is None:
         return None
     else:
+        label = None
+        if js['label'] is not None:
+            label = int(js['label'])
         return ImagePoint(
             index = array_serialization['from_json'](js['index'], manager),
             position = array_serialization['from_json'](js['position'], manager),
             value = array_serialization['from_json'](js['value'], manager),
-            label = int(js['label']),
+            label = label,
         )
 
 def image_point_to_json(image_point, manager=None):
     if image_point is None:
         return None
     else:
+        label = None
+        if image_point.label is not None:
+            label = int(image_point.label)
         return {
             'index': array_serialization['to_json'](image_point.index, manager),
             'position': array_serialization['to_json'](image_point.position,
                 manager),
             'value': array_serialization['to_json'](image_point.value, manager),
-            'label': int(image_point.label, manager),
+            'label': label,
         }
 
 image_point_serialization = {
@@ -715,3 +727,19 @@ class LookupTable(traitlets.Unicode):
                 'Custom'):
             raise self.error('Invalid lookup table')
         return super(LookupTable, self).validate(obj, value)
+
+class Camera(NDArray):
+    """A trait type holding visualization camera parameters."""
+
+    info_text = 'Camera parameters: [[position_x, position_y, position_z], '\
+                                    '[focal_point_x, focal_point_y, focal_point_z], '\
+                                    '[view_up_x, view_up_y, view_up_z]]'
+
+    def validate(self, obj, value):
+        result = value
+        if have_vtk and isinstance(value, vtk.vtkCamera):
+            result = np.zeros((3,3), dtype=np.float32)
+            result[0,:] = value.GetPosition()
+            result[1,:] = value.GetFocalPoint()
+            result[2,:] = value.GetViewUp()
+        return super(Camera, self).validate(obj, result)
