@@ -16,7 +16,7 @@ import numpy as np
 import ipywidgets as widgets
 from traitlets import CBool, CFloat, CInt, Unicode, CaselessStrEnum, List, validate, TraitError, Tuple
 from ipydatawidgets import NDArray, array_serialization, shape_constraints
-from .trait_types import ITKImage, ImagePointTrait, ImagePoint, PointSetList, PolyDataList, itkimage_serialization, image_point_serialization, polydata_list_serialization, Colormap, LookupTable
+from .trait_types import ITKImage, ImagePointTrait, ImagePoint, PointSetList, PolyDataList, itkimage_serialization, image_point_serialization, polydata_list_serialization, Colormap, LookupTable, Camera
 
 try:
     import ipywebrtc
@@ -115,8 +115,8 @@ class Viewer(ViewerParent):
     _model_name = Unicode('ViewerModel').tag(sync=True)
     _view_module = Unicode('itkwidgets').tag(sync=True)
     _model_module = Unicode('itkwidgets').tag(sync=True)
-    _view_module_version = Unicode('^0.31.3').tag(sync=True)
-    _model_module_version = Unicode('^0.31.3').tag(sync=True)
+    _view_module_version = Unicode('^0.32.0').tag(sync=True)
+    _model_module_version = Unicode('^0.32.0').tag(sync=True)
     image = ITKImage(
         default_value=None,
         allow_none=True,
@@ -305,6 +305,10 @@ class Viewer(ViewerParent):
         default_value=True,
         help="Show annotations.").tag(
         sync=True)
+    axes = CBool(
+        default_value=False,
+        help="Display axes.").tag(
+        sync=True)
     mode = CaselessStrEnum(
         ('x',
          'y',
@@ -313,7 +317,7 @@ class Viewer(ViewerParent):
         default_value='v',
         help="View mode: x: x plane, y: y plane, z: z plane, v: volume rendering").tag(
         sync=True)
-    camera = NDArray(dtype=np.float32, default_value=np.zeros((3, 3), dtype=np.float32),
+    camera = Camera(dtype=np.float32, default_value=np.zeros((3, 3), dtype=np.float32),
                      help="Camera parameters: [[position_x, position_y, position_z], "
                      "[focal_point_x, focal_point_y, focal_point_z], "
                      "[view_up_x, view_up_y, view_up_z]]")\
@@ -403,12 +407,6 @@ class Viewer(ViewerParent):
             for dim in range(dimension):
                 if size[dim] > self.size_limit_3d[dim]:
                     self._downsampling = True
-        if self._downsampling and self.image:
-            self.extractor = itk.ExtractImageFilter.New(self.image)
-            self.shrinker = itk.BinShrinkImageFilter.New(self.extractor)
-        if self._downsampling and self.label_image:
-            self.label_image_extractor = itk.ExtractImageFilter.New(self.label_image)
-            self.label_image_shrinker = itk.ShrinkImageFilter.New(self.label_image_extractor)
         self._update_rendered_image()
         if self._downsampling:
             self.observe(self._on_roi_changed, ['roi'])
@@ -488,8 +486,12 @@ class Viewer(ViewerParent):
                     self.size_limit_3d, dimension, size)
             self._scale_factors = np.array(scale_factors, dtype=np.uint8)
             if self.image:
+                self.extractor = itk.ExtractImageFilter.New(self.image)
+                self.shrinker = itk.ShrinkImageFilter.New(self.extractor)
                 self.shrinker.SetShrinkFactors(scale_factors[:dimension])
             if self.label_image:
+                self.label_image_extractor = itk.ExtractImageFilter.New(self.label_image)
+                self.label_image_shrinker = itk.ShrinkImageFilter.New(self.label_image_extractor)
                 self.label_image_shrinker.SetShrinkFactors(scale_factors[:dimension])
 
             region = itk.ImageRegion[dimension]()
@@ -790,7 +792,7 @@ def view(image=None,  # noqa: C901
          point_set_representations=[], point_set_sizes=[],
          geometries=[],
          geometry_colors=[], geometry_opacities=[],
-         ui_collapsed=False, rotate=False, annotations=True, mode='v',
+         ui_collapsed=False, rotate=False, annotations=True, axes=False, mode='v',
          **kwargs):
     """View the image and/or point sets and/or geometries.
 
@@ -827,6 +829,9 @@ def view(image=None,  # noqa: C901
         Display annotations describing orientation and the value of a
         mouse-position-based data probe.
 
+    axes : bool, default: False
+        Display axes.
+
     mode: 'x', 'y', 'z', or 'v', default: 'v'
         Only relevant for 3D scenes.
         Viewing mode:
@@ -835,7 +840,7 @@ def view(image=None,  # noqa: C901
             'z': z-plane
             'v': volume rendering
 
-    camera: 3x3 numpy float32 array
+    camera: 3x3 numpy float32 array, or vtk.vtkCamera
         Camera parameters:
             [[position_x,    position_y,    position_z],
              [focal_point_x, focal_point_y, focal_point_z],
@@ -1076,6 +1081,7 @@ def view(image=None,  # noqa: C901
                     point_set_representations=point_set_representations,
                     point_set_sizes=point_set_sizes,
                     geometries=geometries, geometry_colors=geometry_colors, geometry_opacities=geometry_opacities,
-                    rotate=rotate, ui_collapsed=ui_collapsed, annotations=annotations, mode=mode,
+                    rotate=rotate, ui_collapsed=ui_collapsed,
+                    annotations=annotations, axes=axes, mode=mode,
                     **kwargs)
     return viewer
